@@ -66,6 +66,7 @@ parameter_field_schema = {
 }
 parameter_group_schema = {
     "display_name": {"type": "string", "required": True},
+    "collapsed": {"required": False, "type": "boolean",},
     "shared_parameter_group_uuid": {
         "required": False,
         "dependencies": {"type": ["group"]},
@@ -161,7 +162,13 @@ shared_object_type_schema = {
     "type": {"allowed": ["shared_object_type"], "required": True},
     "parameters": {
         "type": "list",
-        "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
+        "schema": {
+            "type": "dict",
+            "anyof_schema": [
+                parameter_field_schema.copy(),
+                parameter_group_schema.copy(),
+            ],
+        },
     },
 }
 connection_type_schema = {
@@ -185,7 +192,7 @@ connection_type_schema = {
     "type": {"allowed": ["connection"], "required": True},
     "parameters": {
         "type": "list",
-        "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
+        "schema": {"type": "dict", "schema": parameter_group_schema.copy()},
     },
 }
 schemas = {
